# Form implementation generated from reading ui file 'src/magboltz_gui/ui/main.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1301, 912)
        self.centralwidget = QtWidgets.QWidget(parent=MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.mainTab = QtWidgets.QTabWidget(parent=self.centralwidget)
        self.mainTab.setObjectName("mainTab")
        self.tabConfiguration = QtWidgets.QWidget()
        self.tabConfiguration.setObjectName("tabConfiguration")
        self.gridLayout_31 = QtWidgets.QGridLayout(self.tabConfiguration)
        self.gridLayout_31.setObjectName("gridLayout_31")
        self.groupSimParameters = QtWidgets.QGroupBox(parent=self.tabConfiguration)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupSimParameters.sizePolicy().hasHeightForWidth())
        self.groupSimParameters.setSizePolicy(sizePolicy)
        self.groupSimParameters.setObjectName("groupSimParameters")
        self.gridLayout = QtWidgets.QGridLayout(self.groupSimParameters)
        self.gridLayout.setObjectName("gridLayout")
        self.label_4 = QtWidgets.QLabel(parent=self.groupSimParameters)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 2, 1, 1)
        self.spinFinalEnergy = QtWidgets.QDoubleSpinBox(parent=self.groupSimParameters)
        self.spinFinalEnergy.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinFinalEnergy.setObjectName("spinFinalEnergy")
        self.gridLayout.addWidget(self.spinFinalEnergy, 1, 1, 1, 1)
        self.label = QtWidgets.QLabel(parent=self.groupSimParameters)
        self.label.setMinimumSize(QtCore.QSize(200, 0))
        self.label.setToolTip("")
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.label_17 = QtWidgets.QLabel(parent=self.groupSimParameters)
        self.label_17.setObjectName("label_17")
        self.gridLayout.addWidget(self.label_17, 4, 0, 1, 1)
        self.spinRealInteractions = QtWidgets.QSpinBox(parent=self.groupSimParameters)
        self.spinRealInteractions.setMinimumSize(QtCore.QSize(100, 0))
        self.spinRealInteractions.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinRealInteractions.setObjectName("spinRealInteractions")
        self.gridLayout.addWidget(self.spinRealInteractions, 0, 1, 1, 1)
        self.checkPenning = QtWidgets.QCheckBox(parent=self.groupSimParameters)
        self.checkPenning.setMinimumSize(QtCore.QSize(0, 25))
        self.checkPenning.setText("")
        self.checkPenning.setObjectName("checkPenning")
        self.gridLayout.addWidget(self.checkPenning, 2, 1, 1, 1)
        self.checkFinalEnergyAuto = QtWidgets.QCheckBox(parent=self.groupSimParameters)
        self.checkFinalEnergyAuto.setObjectName("checkFinalEnergyAuto")
        self.gridLayout.addWidget(self.checkFinalEnergyAuto, 1, 4, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 4, 1, 1)
        self.label_3 = QtWidgets.QLabel(parent=self.groupSimParameters)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 2, 1, 1)
        self.label_16 = QtWidgets.QLabel(parent=self.groupSimParameters)
        self.label_16.setObjectName("label_16")
        self.gridLayout.addWidget(self.label_16, 2, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(parent=self.groupSimParameters)
        self.label_2.setMinimumSize(QtCore.QSize(0, 0))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.checkThermal = QtWidgets.QCheckBox(parent=self.groupSimParameters)
        self.checkThermal.setMinimumSize(QtCore.QSize(0, 25))
        self.checkThermal.setText("")
        self.checkThermal.setObjectName("checkThermal")
        self.gridLayout.addWidget(self.checkThermal, 4, 1, 1, 1)
        self.gridLayout_31.addWidget(self.groupSimParameters, 0, 0, 1, 1)
        self.groupGasList = QtWidgets.QGroupBox(parent=self.tabConfiguration)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupGasList.sizePolicy().hasHeightForWidth())
        self.groupGasList.setSizePolicy(sizePolicy)
        self.groupGasList.setObjectName("groupGasList")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupGasList)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_12 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_12.setObjectName("label_12")
        self.gridLayout_2.addWidget(self.label_12, 0, 2, 1, 1)
        self.label_6 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 2, 2, 1, 1)
        self.spinGasTemperature = QtWidgets.QDoubleSpinBox(parent=self.groupGasList)
        self.spinGasTemperature.setMinimumSize(QtCore.QSize(100, 0))
        self.spinGasTemperature.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinGasTemperature.setDecimals(1)
        self.spinGasTemperature.setMaximum(500.0)
        self.spinGasTemperature.setObjectName("spinGasTemperature")
        self.gridLayout_2.addWidget(self.spinGasTemperature, 0, 1, 1, 1)
        self.spinGasPressure = QtWidgets.QDoubleSpinBox(parent=self.groupGasList)
        self.spinGasPressure.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinGasPressure.setDecimals(0)
        self.spinGasPressure.setMaximum(10000.0)
        self.spinGasPressure.setSingleStep(10.0)
        self.spinGasPressure.setObjectName("spinGasPressure")
        self.gridLayout_2.addWidget(self.spinGasPressure, 1, 1, 1, 1)
        self.spinMagneticField = QtWidgets.QDoubleSpinBox(parent=self.groupGasList)
        self.spinMagneticField.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinMagneticField.setDecimals(3)
        self.spinMagneticField.setMaximum(10.0)
        self.spinMagneticField.setObjectName("spinMagneticField")
        self.gridLayout_2.addWidget(self.spinMagneticField, 3, 1, 1, 1)
        self.label_8 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 3, 2, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout_2.addItem(spacerItem1, 0, 4, 1, 1)
        self.label_9 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_9.setMinimumSize(QtCore.QSize(200, 0))
        self.label_9.setObjectName("label_9")
        self.gridLayout_2.addWidget(self.label_9, 4, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_7.setMinimumSize(QtCore.QSize(200, 0))
        self.label_7.setObjectName("label_7")
        self.gridLayout_2.addWidget(self.label_7, 3, 0, 1, 1)
        self.label_11 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_11.setMinimumSize(QtCore.QSize(200, 0))
        self.label_11.setObjectName("label_11")
        self.gridLayout_2.addWidget(self.label_11, 0, 0, 1, 1)
        self.spinAngle = QtWidgets.QDoubleSpinBox(parent=self.groupGasList)
        self.spinAngle.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinAngle.setMaximum(359.99)
        self.spinAngle.setObjectName("spinAngle")
        self.gridLayout_2.addWidget(self.spinAngle, 4, 1, 1, 1)
        self.label_14 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_14.setObjectName("label_14")
        self.gridLayout_2.addWidget(self.label_14, 1, 2, 1, 1)
        self.label_5 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_5.setMinimumSize(QtCore.QSize(200, 0))
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 2, 0, 1, 1)
        self.label_13 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_13.setObjectName("label_13")
        self.gridLayout_2.addWidget(self.label_13, 1, 0, 1, 1)
        self.spinElectricField = QtWidgets.QDoubleSpinBox(parent=self.groupGasList)
        self.spinElectricField.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.spinElectricField.setDecimals(0)
        self.spinElectricField.setMaximum(100000.0)
        self.spinElectricField.setSingleStep(100.0)
        self.spinElectricField.setObjectName("spinElectricField")
        self.gridLayout_2.addWidget(self.spinElectricField, 2, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(parent=self.groupGasList)
        self.label_10.setObjectName("label_10")
        self.gridLayout_2.addWidget(self.label_10, 4, 2, 1, 1)
        self.gridLayout_31.addWidget(self.groupGasList, 0, 1, 1, 1)
        self.groupGases = QtWidgets.QGroupBox(parent=self.tabConfiguration)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupGases.sizePolicy().hasHeightForWidth())
        self.groupGases.setSizePolicy(sizePolicy)
        self.groupGases.setObjectName("groupGases")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.groupGases)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.splitterGases = QtWidgets.QSplitter(parent=self.groupGases)
        self.splitterGases.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.splitterGases.setObjectName("splitterGases")
        self.splitterGasesLeft = QtWidgets.QWidget(parent=self.splitterGases)
        self.splitterGasesLeft.setObjectName("splitterGasesLeft")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.splitterGasesLeft)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.widget = QtWidgets.QWidget(parent=self.splitterGasesLeft)
        self.widget.setObjectName("widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnGasAdd = QtWidgets.QToolButton(parent=self.widget)
        icon = QtGui.QIcon.fromTheme("list-add")
        self.btnGasAdd.setIcon(icon)
        self.btnGasAdd.setObjectName("btnGasAdd")
        self.horizontalLayout.addWidget(self.btnGasAdd)
        self.btnGasRemove = QtWidgets.QToolButton(parent=self.widget)
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.btnGasRemove.setIcon(icon)
        self.btnGasRemove.setObjectName("btnGasRemove")
        self.horizontalLayout.addWidget(self.btnGasRemove)
        self.btnGasNormalize = QtWidgets.QToolButton(parent=self.widget)
        icon = QtGui.QIcon.fromTheme("accessories-calculator")
        self.btnGasNormalize.setIcon(icon)
        self.btnGasNormalize.setObjectName("btnGasNormalize")
        self.horizontalLayout.addWidget(self.btnGasNormalize)
        self.lblNeedNormalize = QtWidgets.QLabel(parent=self.widget)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(192, 28, 40))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(190, 190, 190))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.WindowText, brush)
        self.lblNeedNormalize.setPalette(palette)
        font = QtGui.QFont()
        font.setBold(True)
        self.lblNeedNormalize.setFont(font)
        self.lblNeedNormalize.setObjectName("lblNeedNormalize")
        self.horizontalLayout.addWidget(self.lblNeedNormalize)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem2)
        self.btnGasUp = QtWidgets.QToolButton(parent=self.widget)
        icon = QtGui.QIcon.fromTheme("go-up")
        self.btnGasUp.setIcon(icon)
        self.btnGasUp.setObjectName("btnGasUp")
        self.horizontalLayout.addWidget(self.btnGasUp)
        self.btnGasDown = QtWidgets.QToolButton(parent=self.widget)
        icon = QtGui.QIcon.fromTheme("go-down")
        self.btnGasDown.setIcon(icon)
        self.btnGasDown.setObjectName("btnGasDown")
        self.horizontalLayout.addWidget(self.btnGasDown)
        self.verticalLayout_2.addWidget(self.widget)
        self.gasListTable = QtWidgets.QTableWidget(parent=self.splitterGasesLeft)
        self.gasListTable.setColumnCount(3)
        self.gasListTable.setObjectName("gasListTable")
        self.gasListTable.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.gasListTable.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        item.setTextAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.gasListTable.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        item.setTextAlignment(QtCore.Qt.AlignmentFlag.AlignLeading|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.gasListTable.setHorizontalHeaderItem(2, item)
        self.verticalLayout_2.addWidget(self.gasListTable)
        self.splitterGasRight = QtWidgets.QWidget(parent=self.splitterGases)
        self.splitterGasRight.setObjectName("splitterGasRight")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.splitterGasRight)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.widget_3 = QtWidgets.QWidget(parent=self.splitterGasRight)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_3.sizePolicy().hasHeightForWidth())
        self.widget_3.setSizePolicy(sizePolicy)
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_18 = QtWidgets.QLabel(parent=self.widget_3)
        self.label_18.setObjectName("label_18")
        self.horizontalLayout_4.addWidget(self.label_18)
        self.cmbLabelFormat = QtWidgets.QComboBox(parent=self.widget_3)
        self.cmbLabelFormat.setObjectName("cmbLabelFormat")
        self.cmbLabelFormat.addItem("")
        self.cmbLabelFormat.addItem("")
        self.cmbLabelFormat.addItem("")
        self.cmbLabelFormat.addItem("")
        self.horizontalLayout_4.addWidget(self.cmbLabelFormat)
        self.label_19 = QtWidgets.QLabel(parent=self.widget_3)
        self.label_19.setObjectName("label_19")
        self.horizontalLayout_4.addWidget(self.label_19)
        self.cmbColorMap = QtWidgets.QComboBox(parent=self.widget_3)
        self.cmbColorMap.setObjectName("cmbColorMap")
        self.horizontalLayout_4.addWidget(self.cmbColorMap)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem3)
        self.btnGraphSave = QtWidgets.QToolButton(parent=self.widget_3)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.btnGraphSave.setIcon(icon)
        self.btnGraphSave.setIconSize(QtCore.QSize(16, 16))
        self.btnGraphSave.setToolButtonStyle(QtCore.Qt.ToolButtonStyle.ToolButtonIconOnly)
        self.btnGraphSave.setObjectName("btnGraphSave")
        self.horizontalLayout_4.addWidget(self.btnGraphSave)
        self.verticalLayout_5.addWidget(self.widget_3)
        self.pieContainer = QtWidgets.QFrame(parent=self.splitterGasRight)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pieContainer.sizePolicy().hasHeightForWidth())
        self.pieContainer.setSizePolicy(sizePolicy)
        self.pieContainer.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.pieContainer.setFrameShadow(QtWidgets.QFrame.Shadow.Raised)
        self.pieContainer.setObjectName("pieContainer")
        self.verticalLayout_5.addWidget(self.pieContainer)
        self.horizontalLayout_3.addWidget(self.splitterGases)
        self.gridLayout_31.addWidget(self.groupGases, 1, 0, 1, 2)
        self.mainTab.addTab(self.tabConfiguration, "")
        self.tabExecution = QtWidgets.QWidget()
        self.tabExecution.setObjectName("tabExecution")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tabExecution)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.widget_2 = QtWidgets.QWidget(parent=self.tabExecution)
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_15 = QtWidgets.QLabel(parent=self.widget_2)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_2.addWidget(self.label_15)
        self.commandLine = QtWidgets.QLineEdit(parent=self.widget_2)
        self.commandLine.setReadOnly(True)
        self.commandLine.setObjectName("commandLine")
        self.horizontalLayout_2.addWidget(self.commandLine)
        self.btnCmdCopyToClipbord = QtWidgets.QToolButton(parent=self.widget_2)
        icon = QtGui.QIcon.fromTheme("edit-copy")
        self.btnCmdCopyToClipbord.setIcon(icon)
        self.btnCmdCopyToClipbord.setObjectName("btnCmdCopyToClipbord")
        self.horizontalLayout_2.addWidget(self.btnCmdCopyToClipbord)
        self.btnResultSave = QtWidgets.QToolButton(parent=self.widget_2)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.btnResultSave.setIcon(icon)
        self.btnResultSave.setObjectName("btnResultSave")
        self.horizontalLayout_2.addWidget(self.btnResultSave)
        self.btnResultExport = QtWidgets.QToolButton(parent=self.widget_2)
        icon = QtGui.QIcon.fromTheme("x-office-spreadsheet")
        self.btnResultExport.setIcon(icon)
        self.btnResultExport.setObjectName("btnResultExport")
        self.horizontalLayout_2.addWidget(self.btnResultExport)
        self.verticalLayout_4.addWidget(self.widget_2)
        self.consoleOutput = QtWidgets.QTextEdit(parent=self.tabExecution)
        font = QtGui.QFont()
        font.setFamily("Monospace")
        self.consoleOutput.setFont(font)
        self.consoleOutput.setReadOnly(True)
        self.consoleOutput.setObjectName("consoleOutput")
        self.verticalLayout_4.addWidget(self.consoleOutput)
        self.mainTab.addTab(self.tabExecution, "")
        self.gridLayout_3.addWidget(self.mainTab, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.mainMenuBar = QtWidgets.QMenuBar(parent=MainWindow)
        self.mainMenuBar.setGeometry(QtCore.QRect(0, 0, 1301, 23))
        self.mainMenuBar.setObjectName("mainMenuBar")
        self.menu_File = QtWidgets.QMenu(parent=self.mainMenuBar)
        self.menu_File.setObjectName("menu_File")
        self.menu_Edit = QtWidgets.QMenu(parent=self.mainMenuBar)
        self.menu_Edit.setObjectName("menu_Edit")
        self.menu_Help = QtWidgets.QMenu(parent=self.mainMenuBar)
        self.menu_Help.setSeparatorsCollapsible(False)
        self.menu_Help.setObjectName("menu_Help")
        self.menuRun = QtWidgets.QMenu(parent=self.mainMenuBar)
        self.menuRun.setObjectName("menuRun")
        MainWindow.setMenuBar(self.mainMenuBar)
        self.mainToolBar = QtWidgets.QToolBar(parent=MainWindow)
        self.mainToolBar.setObjectName("mainToolBar")
        MainWindow.addToolBar(QtCore.Qt.ToolBarArea.TopToolBarArea, self.mainToolBar)
        self.actionNew = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-new")
        self.actionNew.setIcon(icon)
        self.actionNew.setObjectName("actionNew")
        self.actionOpen = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-open")
        self.actionOpen.setIcon(icon)
        self.actionOpen.setObjectName("actionOpen")
        self.actionQuit = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("application-exit")
        self.actionQuit.setIcon(icon)
        self.actionQuit.setObjectName("actionQuit")
        self.actionSave = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-save")
        self.actionSave.setIcon(icon)
        self.actionSave.setObjectName("actionSave")
        self.actionClose = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-delete")
        self.actionClose.setIcon(icon)
        self.actionClose.setObjectName("actionClose")
        self.actionSaveAs = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.actionSaveAs.setIcon(icon)
        self.actionSaveAs.setObjectName("actionSaveAs")
        self.actionRevert = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-revert")
        self.actionRevert.setIcon(icon)
        self.actionRevert.setObjectName("actionRevert")
        self.actionRun = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("system-run")
        self.actionRun.setIcon(icon)
        self.actionRun.setObjectName("actionRun")
        self.actionGasAdd = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("list-add")
        self.actionGasAdd.setIcon(icon)
        self.actionGasAdd.setObjectName("actionGasAdd")
        self.actionGasRemove = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("list-remove")
        self.actionGasRemove.setIcon(icon)
        self.actionGasRemove.setObjectName("actionGasRemove")
        self.actionGasNormalize = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("accessories-calculator")
        self.actionGasNormalize.setIcon(icon)
        self.actionGasNormalize.setObjectName("actionGasNormalize")
        self.actionResultExport = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("x-office-spreadsheet")
        self.actionResultExport.setIcon(icon)
        self.actionResultExport.setObjectName("actionResultExport")
        self.actionCmdCopyToClipboard = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("edit-copy")
        self.actionCmdCopyToClipboard.setIcon(icon)
        self.actionCmdCopyToClipboard.setObjectName("actionCmdCopyToClipboard")
        self.actionResultSave = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.actionResultSave.setIcon(icon)
        self.actionResultSave.setObjectName("actionResultSave")
        self.actionGraphSave = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("document-save-as")
        self.actionGraphSave.setIcon(icon)
        self.actionGraphSave.setObjectName("actionGraphSave")
        self.actionGasMoveUp = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("go-up")
        self.actionGasMoveUp.setIcon(icon)
        self.actionGasMoveUp.setObjectName("actionGasMoveUp")
        self.actionGasMoveDown = QtGui.QAction(parent=MainWindow)
        icon = QtGui.QIcon.fromTheme("go-down")
        self.actionGasMoveDown.setIcon(icon)
        self.actionGasMoveDown.setObjectName("actionGasMoveDown")
        self.menu_File.addAction(self.actionNew)
        self.menu_File.addAction(self.actionOpen)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.actionSave)
        self.menu_File.addAction(self.actionSaveAs)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.actionRevert)
        self.menu_File.addAction(self.actionClose)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.actionQuit)
        self.menu_Edit.addSeparator()
        self.menuRun.addAction(self.actionRun)
        self.menuRun.addSeparator()
        self.menuRun.addAction(self.actionResultSave)
        self.menuRun.addAction(self.actionResultExport)
        self.mainMenuBar.addAction(self.menu_File.menuAction())
        self.mainMenuBar.addAction(self.menu_Edit.menuAction())
        self.mainMenuBar.addAction(self.menuRun.menuAction())
        self.mainMenuBar.addAction(self.menu_Help.menuAction())
        self.mainToolBar.addAction(self.actionNew)
        self.mainToolBar.addAction(self.actionOpen)
        self.mainToolBar.addSeparator()
        self.mainToolBar.addAction(self.actionSave)
        self.mainToolBar.addAction(self.actionSaveAs)
        self.mainToolBar.addSeparator()
        self.mainToolBar.addAction(self.actionRevert)
        self.mainToolBar.addSeparator()
        self.mainToolBar.addAction(self.actionRun)

        self.retranslateUi(MainWindow)
        self.mainTab.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Magboltz GUI"))
        self.groupSimParameters.setTitle(_translate("MainWindow", "SImulation parameters"))
        self.label_4.setText(_translate("MainWindow", "eV"))
        self.spinFinalEnergy.setToolTip(_translate("MainWindow", "EFINAL: upper limit of the electron energy in electron Volts, if EFINAL = 0.0, program automatically calculates upper integration energy limit"))
        self.label.setText(_translate("MainWindow", "Real interactions"))
        self.label_17.setText(_translate("MainWindow", "Enable thermal motion"))
        self.spinRealInteractions.setToolTip(_translate("MainWindow", " NMAX: Number of real collisions, use a value between 2 and 5 for inelastic gas to obtain 1% accuracy, use a value above 10 for better than 0.5 % accuracy and a value of at least 10 for pure elastic gases like Argon"))
        self.checkPenning.setToolTip(_translate("MainWindow", "IPEN: include Penning effect"))
        self.checkFinalEnergyAuto.setText(_translate("MainWindow", "Auto"))
        self.label_3.setText(_translate("MainWindow", "× 10⁷"))
        self.label_16.setText(_translate("MainWindow", "Enable Penning effect"))
        self.label_2.setText(_translate("MainWindow", "Final energy"))
        self.checkThermal.setToolTip(_translate("MainWindow", "ITHRM: gas motion taken to be at input temperature"))
        self.groupGasList.setTitle(_translate("MainWindow", "Conditions"))
        self.label_12.setText(_translate("MainWindow", "℃"))
        self.label_6.setText(_translate("MainWindow", "V/cm"))
        self.spinGasTemperature.setToolTip(_translate("MainWindow", "TEMP: temperature of gas in centigrade"))
        self.spinGasPressure.setToolTip(_translate("MainWindow", "TORR: pressure of gas in Torr"))
        self.spinMagneticField.setToolTip(_translate("MainWindow", "BMAG: magnitude of the magnetic field in kilogauss"))
        self.label_8.setText(_translate("MainWindow", "kG"))
        self.label_9.setText(_translate("MainWindow", "Angle"))
        self.label_7.setText(_translate("MainWindow", "Magnetic field"))
        self.label_11.setText(_translate("MainWindow", "Gas temperature"))
        self.spinAngle.setToolTip(_translate("MainWindow", "BTHETA: angle between the electric and magnetic fields in degrees"))
        self.label_14.setText(_translate("MainWindow", "Torr"))
        self.label_5.setText(_translate("MainWindow", "Electric field"))
        self.label_13.setText(_translate("MainWindow", "Gas pressure"))
        self.spinElectricField.setToolTip(_translate("MainWindow", "EFIELD: electric field in Volt/cm"))
        self.label_10.setText(_translate("MainWindow", "°"))
        self.groupGases.setTitle(_translate("MainWindow", "Gas components"))
        self.btnGasAdd.setText(_translate("MainWindow", "..."))
        self.btnGasRemove.setText(_translate("MainWindow", "..."))
        self.btnGasNormalize.setToolTip(_translate("MainWindow", "Normalize gas fractions"))
        self.btnGasNormalize.setText(_translate("MainWindow", "..."))
        self.lblNeedNormalize.setText(_translate("MainWindow", "gas fractions needs to be normalized"))
        self.btnGasUp.setText(_translate("MainWindow", "..."))
        self.btnGasDown.setText(_translate("MainWindow", "..."))
        item = self.gasListTable.horizontalHeaderItem(0)
        item.setText(_translate("MainWindow", "Gas ID"))
        item = self.gasListTable.horizontalHeaderItem(1)
        item.setText(_translate("MainWindow", "Gas name"))
        item = self.gasListTable.horizontalHeaderItem(2)
        item.setText(_translate("MainWindow", "Gas fraction"))
        self.label_18.setText(_translate("MainWindow", "Label"))
        self.cmbLabelFormat.setItemText(0, _translate("MainWindow", "Formula"))
        self.cmbLabelFormat.setItemText(1, _translate("MainWindow", "Name"))
        self.cmbLabelFormat.setItemText(2, _translate("MainWindow", "Name (formula)"))
        self.cmbLabelFormat.setItemText(3, _translate("MainWindow", "None"))
        self.label_19.setText(_translate("MainWindow", "Colors"))
        self.btnGraphSave.setText(_translate("MainWindow", "..."))
        self.mainTab.setTabText(self.mainTab.indexOf(self.tabConfiguration), _translate("MainWindow", "Configuration"))
        self.label_15.setText(_translate("MainWindow", "Command line"))
        self.commandLine.setPlaceholderText(_translate("MainWindow", "(save the current file)"))
        self.btnCmdCopyToClipbord.setText(_translate("MainWindow", "..."))
        self.btnResultSave.setText(_translate("MainWindow", "..."))
        self.btnResultExport.setText(_translate("MainWindow", "..."))
        self.mainTab.setTabText(self.mainTab.indexOf(self.tabExecution), _translate("MainWindow", "Execution"))
        self.menu_File.setTitle(_translate("MainWindow", "&File"))
        self.menu_Edit.setTitle(_translate("MainWindow", "&Edit"))
        self.menu_Help.setTitle(_translate("MainWindow", "&Help"))
        self.menuRun.setTitle(_translate("MainWindow", "Run"))
        self.mainToolBar.setWindowTitle(_translate("MainWindow", "toolBar"))
        self.actionNew.setText(_translate("MainWindow", "&New"))
        self.actionOpen.setText(_translate("MainWindow", "&Open"))
        self.actionQuit.setText(_translate("MainWindow", "&Exit"))
        self.actionSave.setText(_translate("MainWindow", "&Save"))
        self.actionClose.setText(_translate("MainWindow", "Close"))
        self.actionSaveAs.setText(_translate("MainWindow", "Save As"))
        self.actionRevert.setText(_translate("MainWindow", "Revert"))
        self.actionRun.setText(_translate("MainWindow", "Run"))
        self.actionGasAdd.setText(_translate("MainWindow", "Add"))
        self.actionGasRemove.setText(_translate("MainWindow", "Remove"))
        self.actionGasNormalize.setText(_translate("MainWindow", "Normalize"))
        self.actionGasNormalize.setToolTip(_translate("MainWindow", "Normalize"))
        self.actionResultExport.setText(_translate("MainWindow", "Export"))
        self.actionCmdCopyToClipboard.setText(_translate("MainWindow", "Cooy to clipboard"))
        self.actionCmdCopyToClipboard.setShortcut(_translate("MainWindow", "Ctrl+C"))
        self.actionResultSave.setText(_translate("MainWindow", "Save"))
        self.actionGraphSave.setText(_translate("MainWindow", "Save graph"))
        self.actionGasMoveUp.setText(_translate("MainWindow", "Move up"))
        self.actionGasMoveDown.setText(_translate("MainWindow", "Move down"))
