from typing import Any
from PyQt6 import QtCore, QtGui, QtWidgets

class Ui_MainWindow:
    MainWindow: QtWidgets.QMainWindow
    actionClose: QtGui.QAction
    actionCmdCopyToClipboard: QtGui.QAction
    actionGasAdd: QtGui.QAction
    actionGasMoveDown: QtGui.QAction
    actionGasMoveUp: QtGui.QAction
    actionGasNormalize: QtGui.QAction
    actionGasRemove: QtGui.QAction
    actionGraphSave: QtGui.QAction
    actionNew: QtGui.QAction
    actionOpen: QtGui.QAction
    actionQuit: QtGui.QAction
    actionResultExport: QtGui.QAction
    actionResultSave: QtGui.QAction
    actionRevert: QtGui.QAction
    actionRun: QtGui.QAction
    actionSave: QtGui.QAction
    actionSaveAs: QtGui.QAction
    btnCmdCopyToClipbord: QtWidgets.QToolButton
    btnGasAdd: QtWidgets.QToolButton
    btnGasDown: QtWidgets.QToolButton
    btnGasNormalize: QtWidgets.QToolButton
    btnGasRemove: QtWidgets.QToolButton
    btnGasUp: QtWidgets.QToolButton
    btnGraphSave: QtWidgets.QToolButton
    btnResultExport: QtWidgets.QToolButton
    btnResultSave: QtWidgets.QToolButton
    centralwidget: QtWidgets.QWidget
    checkFinalEnergyAuto: QtWidgets.QCheckBox
    checkPenning: QtWidgets.QCheckBox
    checkThermal: QtWidgets.QCheckBox
    cmbColorMap: QtWidgets.QComboBox
    cmbLabelFormat: QtWidgets.QComboBox
    commandLine: QtWidgets.QLineEdit
    consoleOutput: QtWidgets.QTextEdit
    gasListTable: QtWidgets.QTableWidget
    gridLayout: QtWidgets.QGridLayout
    gridLayout_2: QtWidgets.QGridLayout
    gridLayout_3: QtWidgets.QGridLayout
    groupGasList: QtWidgets.QGroupBox
    groupGases: QtWidgets.QGroupBox
    groupSimParameters: QtWidgets.QGroupBox
    horizontalLayout: QtWidgets.QHBoxLayout
    horizontalLayout_2: QtWidgets.QHBoxLayout
    horizontalLayout_3: QtWidgets.QHBoxLayout
    horizontalLayout_4: QtWidgets.QHBoxLayout
    horizontalSpacer: QtWidgets.QSpacerItem
    horizontalSpacer_2: QtWidgets.QSpacerItem
    horizontalSpacer_3: QtWidgets.QSpacerItem
    horizontalSpacer_6: QtWidgets.QSpacerItem
    label: QtWidgets.QLabel
    label_10: QtWidgets.QLabel
    label_11: QtWidgets.QLabel
    label_12: QtWidgets.QLabel
    label_13: QtWidgets.QLabel
    label_14: QtWidgets.QLabel
    label_15: QtWidgets.QLabel
    label_16: QtWidgets.QLabel
    label_17: QtWidgets.QLabel
    label_18: QtWidgets.QLabel
    label_19: QtWidgets.QLabel
    label_2: QtWidgets.QLabel
    label_3: QtWidgets.QLabel
    label_4: QtWidgets.QLabel
    label_5: QtWidgets.QLabel
    label_6: QtWidgets.QLabel
    label_7: QtWidgets.QLabel
    label_8: QtWidgets.QLabel
    label_9: QtWidgets.QLabel
    lblNeedNormalize: QtWidgets.QLabel
    mainMenuBar: QtWidgets.QMenuBar
    mainTab: QtWidgets.QTabWidget
    mainToolBar: QtWidgets.QToolBar
    menuRun: QtWidgets.QMenu
    menu_Edit: QtWidgets.QMenu
    menu_File: QtWidgets.QMenu
    menu_Help: QtWidgets.QMenu
    pieContainer: QtWidgets.QFrame
    spinAngle: QtWidgets.QDoubleSpinBox
    spinElectricField: QtWidgets.QDoubleSpinBox
    spinFinalEnergy: QtWidgets.QDoubleSpinBox
    spinGasPressure: QtWidgets.QDoubleSpinBox
    spinGasTemperature: QtWidgets.QDoubleSpinBox
    spinMagneticField: QtWidgets.QDoubleSpinBox
    spinRealInteractions: QtWidgets.QSpinBox
    splitterGasRight: QtWidgets.QWidget
    splitterGases: QtWidgets.QSplitter
    splitterGasesLeft: QtWidgets.QWidget
    tabConfiguration: QtWidgets.QWidget
    tabExecution: QtWidgets.QWidget
    verticalLayout_2: QtWidgets.QVBoxLayout
    verticalLayout_4: QtWidgets.QVBoxLayout
    verticalLayout_5: QtWidgets.QVBoxLayout
    widget: QtWidgets.QWidget
    widget_2: QtWidgets.QWidget
    widget_3: QtWidgets.QWidget
    def setupUi(self, widget: QtWidgets.QMainWindow) -> None: ...
    def retranslateUi(self, widget: QtWidgets.QMainWindow) -> None: ...