from typing import Any
from PyQt6 import QtCore, QtGui, QtWidgets

class Ui_SearchGasForm:
    SearchGasForm: QtWidgets.QWidget
    dialogButtons: QtWidgets.QDialogButtonBox
    horizontalLayout: QtWidgets.QHBoxLayout
    horizontalLayout_2: QtWidgets.QHBoxLayout
    horizontalLayout_3: QtWidgets.QHBoxLayout
    horizontalSpacer: QtWidgets.QSpacerItem
    horizontalSpacer_2: QtWidgets.QSpacerItem
    label: QtWidgets.QLabel
    label_5: QtWidgets.QLabel
    label_note: QtWidgets.QLabel
    label_rating: QtWidgets.QLabel
    label_year: QtWidgets.QLabel
    searchBarText: QtWidgets.QLineEdit
    searchResultTable: QtWidgets.QTableWidget
    verticalLayout: QtWidgets.QVBoxLayout
    widget: QtWidgets.QWidget
    widget_2: QtWidgets.QWidget
    widget_3: QtWidgets.QWidget
    def setupUi(self, widget: QtWidgets.QWidget) -> None: ...
    def retranslateUi(self, widget: QtWidgets.QWidget) -> None: ...