# Form implementation generated from reading ui file 'src/magboltz_gui/ui/search.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_SearchGasForm(object):
    def setupUi(self, SearchGasForm):
        SearchGasForm.setObjectName("SearchGasForm")
        SearchGasForm.resize(377, 886)
        self.verticalLayout = QtWidgets.QVBoxLayout(SearchGasForm)
        self.verticalLayout.setObjectName("verticalLayout")
        self.searchBarText = QtWidgets.QLineEdit(parent=SearchGasForm)
        self.searchBarText.setObjectName("searchBarText")
        self.verticalLayout.addWidget(self.searchBarText)
        self.searchResultTable = QtWidgets.QTableWidget(parent=SearchGasForm)
        self.searchResultTable.setObjectName("searchResultTable")
        self.searchResultTable.setColumnCount(0)
        self.searchResultTable.setRowCount(0)
        self.verticalLayout.addWidget(self.searchResultTable)
        self.widget_2 = QtWidgets.QWidget(parent=SearchGasForm)
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(parent=self.widget_2)
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.label_year = QtWidgets.QLabel(parent=self.widget_2)
        self.label_year.setObjectName("label_year")
        self.horizontalLayout_2.addWidget(self.label_year)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.label_5 = QtWidgets.QLabel(parent=self.widget_2)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_2.addWidget(self.label_5)
        self.label_rating = QtWidgets.QLabel(parent=self.widget_2)
        self.label_rating.setObjectName("label_rating")
        self.horizontalLayout_2.addWidget(self.label_rating)
        self.verticalLayout.addWidget(self.widget_2)
        self.widget_3 = QtWidgets.QWidget(parent=SearchGasForm)
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_note = QtWidgets.QLabel(parent=self.widget_3)
        self.label_note.setWordWrap(True)
        self.label_note.setObjectName("label_note")
        self.horizontalLayout_3.addWidget(self.label_note)
        self.verticalLayout.addWidget(self.widget_3)
        self.widget = QtWidgets.QWidget(parent=SearchGasForm)
        self.widget.setObjectName("widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem1 = QtWidgets.QSpacerItem(977, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.dialogButtons = QtWidgets.QDialogButtonBox(parent=self.widget)
        self.dialogButtons.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.dialogButtons.setObjectName("dialogButtons")
        self.horizontalLayout.addWidget(self.dialogButtons)
        self.verticalLayout.addWidget(self.widget)

        self.retranslateUi(SearchGasForm)
        QtCore.QMetaObject.connectSlotsByName(SearchGasForm)

    def retranslateUi(self, SearchGasForm):
        _translate = QtCore.QCoreApplication.translate
        SearchGasForm.setWindowTitle(_translate("SearchGasForm", "Form"))
        self.searchBarText.setPlaceholderText(_translate("SearchGasForm", "(search here)"))
        self.label.setText(_translate("SearchGasForm", "Year: "))
        self.label_year.setText(_translate("SearchGasForm", "(year)"))
        self.label_5.setText(_translate("SearchGasForm", "Rating:"))
        self.label_rating.setText(_translate("SearchGasForm", "(rating)"))
        self.label_note.setText(_translate("SearchGasForm", "(note)"))
